@@ -21,7 +21,7 @@ func (root *Root) toggleWrapMode() {
 	root.setMessagef("Set WrapMode %t", root.Doc.WrapMode)
 }
 
-//  toggleColumnMode toggles ColumnMode each time it is called.
+// toggleColumnMode toggles ColumnMode each time it is called.
 func (root *Root) toggleColumnMode() {
 	root.Doc.ColumnMode = !root.Doc.ColumnMode
 	root.setMessagef("Set ColumnMode %t", root.Doc.ColumnMode)
@@ -196,7 +196,7 @@ func (root *Root) markPrev() {
 // addMark marks the current line number.
 func (root *Root) addMark() {
 	c := min(root.Doc.topLN+root.Doc.firstLine(), root.Doc.BufEndNum())
-	root.Doc.marked = removeInt(root.Doc.marked, c)
+	root.Doc.marked = remove(root.Doc.marked, c)
 	root.Doc.marked = append(root.Doc.marked, c)
 	root.setMessagef("Marked to line %d", c-root.Doc.firstLine()+1)
 }
@@ -204,7 +204,7 @@ func (root *Root) addMark() {
 // removeMark removes the current line number from the mark.
 func (root *Root) removeMark() {
 	c := root.Doc.topLN + root.Doc.firstLine()
-	marked := removeInt(root.Doc.marked, c)
+	marked := remove(root.Doc.marked, c)
 	if len(root.Doc.marked) == len(marked) {
 		root.setMessagef("Not marked line %d", c-root.Doc.firstLine()+1)
 		return
@@ -297,7 +297,7 @@ func (root *Root) toggleMouse() {
 		root.Screen.DisableMouse()
 		root.setMessage("Disable Mouse")
 	} else {
-		root.Screen.EnableMouse()
+		root.Screen.EnableMouse(MouseFlags)
 		root.setMessage("Enable Mouse")
 	}
 }
