@@ -195,6 +195,8 @@ type Config struct {
 	// Debug represents whether to enable the debug output.
 	Debug bool
 
+	// Default keybindings. Disabled if the default keybinding is "disable".
+	DefaultKeyBind string
 	// KeyBinding
 	Keybind map[string][]string
 
@@ -261,6 +263,10 @@ const (
 	LogDoc
 )
 
+// Set the mode to MouseDragEvents when the mouse is enabled in oviewer.
+// Does not track mouse movements except when dragging.
+const MouseFlags = tcell.MouseDragEvents
+
 const MaxWriteLog int = 10
 
 var (
@@ -480,7 +486,7 @@ func (root *Root) SetWatcher(watcher *fsnotify.Watcher) {
 }
 
 func (root *Root) setKeyConfig() (map[string][]string, error) {
-	keyBind := GetKeyBinds(root.Config.Keybind)
+	keyBind := GetKeyBinds(root.Config)
 	if err := root.setKeyBind(keyBind); err != nil {
 		return nil, err
 	}
@@ -523,7 +529,7 @@ func (root *Root) Run() error {
 	root.helpDoc = help
 
 	if !root.Config.DisableMouse {
-		root.Screen.EnableMouse()
+		root.Screen.EnableMouse(MouseFlags)
 	}
 	root.Config.General.SectionDelimiterReg = regexpCompile(root.Config.General.SectionDelimiter, true)
 
